.. _pydl.photoop:

===================================
SDSS Imaging Data  (`pydl.photoop`)
===================================

Introduction
------------

This is a placeholder for photoop documentation.

.. automodapi:: pydl.photoop
   :no-inheritance-diagram:
